@@ -20,6 +20,7 @@ module Graphics.Rendering.Chart.Plot(
     module Graphics.Rendering.Chart.Plot.Annotation,
     module Graphics.Rendering.Chart.Plot.AreaSpots,
     module Graphics.Rendering.Chart.Plot.Pie,
+    module Graphics.Rendering.Chart.Plot.Histogram,
 ) where
 
 import Graphics.Rendering.Chart.Plot.Types
@@ -34,3 +35,4 @@ import Graphics.Rendering.Chart.Plot.Hidden
 import Graphics.Rendering.Chart.Plot.Annotation
 import Graphics.Rendering.Chart.Plot.AreaSpots
 import Graphics.Rendering.Chart.Plot.Pie
+import Graphics.Rendering.Chart.Plot.Histogram
